@@ -17,7 +17,7 @@ from contrast.agent.assess.utils import (
 )
 from contrast.utils.decorators import fail_safely
 
-from contrast.extern.backports.functools_lru_cache import lru_cache
+from functools import lru_cache
 
 from .split_propagator import SplitPropagator
 
