@@ -10,7 +10,16 @@ from contrast.extern import structlog as logging
 logger = logging.getLogger("contrast")
 
 Version = namedtuple("Version", ["major", "minor", "patch"])
-SUPPORTED_FRAMEWORKS = ["django", "falcon", "flask", "pyramid"]
+SUPPORTED_FRAMEWORKS = [
+    "django",
+    "falcon",
+    "flask",
+    "pyramid",
+    "aiohttp",
+    "bottle",
+    "fastapi",
+    "quart",
+]
 DEFAULT_FRAMEWORK = "WSGI"
 SUPPORTED_SERVERS = ["uwsgi", "gunicorn", "uvicorn"]
 DEFAULT_SERVER = "Unknown"
