@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import threading
 from contrast.agent import scope
@@ -14,7 +14,7 @@ logger = logging.getLogger("contrast")
 
 class Heartbeat(threading.Thread):
     def __init__(self, settings):
-        super(Heartbeat, self).__init__()
+        super().__init__()
         self.daemon = True
         self.settings = settings
         self.stopped = False
