@@ -6,7 +6,7 @@ import platform
 import sys
 
 from contrast import __version__, AGENT_CURR_WORKING_DIR
-from contrast.reporting.teamserver_messages import ServerActivity
+from contrast.reporting import teamserver_messages
 from contrast.agent.patch_controller import disable_assess_patches
 from contrast.agent import patch_controller, service_client, scope
 from contrast.agent.telemetry import telemetry_disabled
@@ -15,7 +15,7 @@ from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.assess.preflight import update_preflight_hashes
 from contrast.agent.assess.rules.providers.enable import enable_providers
 from contrast.agent.middlewares.route_coverage.routes_mixin import RoutesMixin
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.agent.speedracer_input_analysis import get_input_analysis
 from contrast.api.dtm_pb2 import AttackResult
 from contrast.reporting import ReportingClient
@@ -159,7 +159,7 @@ class BaseMiddleware(RoutesMixin):
         Returns True on settings being initialized and False if any failure.
         """
         try:
-            self.settings = SettingsState(app_name=app_name)
+            self.settings = Settings(app_name=app_name)
         except Exception as e:
             logger.error(e)
             return False
@@ -242,7 +242,9 @@ class BaseMiddleware(RoutesMixin):
             else service_client.send_messages
         )
 
-        self.library_reader = LibraryReader(send_message_func=send_message_func)
+        self.library_reader = LibraryReader(
+            self.settings, send_message_func=send_message_func
+        )
         self.library_reader.start_library_analysis_thread()
 
     def is_agent_enabled(self):
@@ -273,7 +275,7 @@ class BaseMiddleware(RoutesMixin):
     def call_with_agent(self, context, environ, start_response):
         pass
 
-    def call_without_agent(self):
+    def call_without_agent(self, path):
         """
         If Agent is either disabled or not initialized due to either entire settings
         initialization failing or just loggers failing, then we should print to stdout
@@ -288,7 +290,7 @@ class BaseMiddleware(RoutesMixin):
         """
         disable_assess_patches()
 
-        logger.warning("Contrast Agent is not running.")
+        logger.warning("Contrast Agent did not analyze request %s", path)
 
     def handle_ensure(self, context, request):
         """
@@ -308,15 +310,34 @@ class BaseMiddleware(RoutesMixin):
 
             logger.debug("Sending final messages for reporting.")
 
-            if self.reporting_client:
-                for msg in self.final_ts_messages():
-                    self.reporting_client.add_message(msg)
-
             final_messages = self.final_messages(context)
             service_client.send_messages(final_messages)
 
-    def final_ts_messages(self):
-        return [ServerActivity()]
+            if self.reporting_client:
+                for msg in self.final_ts_messages(context):
+                    self.reporting_client.add_message(msg)
+
+        self.first_request = False
+
+    def final_ts_messages(self, context):
+        messages = [
+            teamserver_messages.ServerActivity(),
+            teamserver_messages.Preflight(context.activity.findings),
+        ]
+
+        # Currently we do not report an observed route if the route signature is empty.
+        # As a team we've decided there isn't a meaningful default signature value
+        # we can provide to customers. If a route doesn't show up in Contrast UI,
+        # it may be due to its missing signature. In this scenario, we will have to work
+        # with the customer directly to understand why the signature was not created.
+        if self.settings.is_assess_enabled() and context.observed_route.signature:
+            messages.append(teamserver_messages.ObservedRoute(context.observed_route))
+
+        if self.first_request and self.settings.is_inventory_enabled():
+            # ApplicationUpdate message only sent at first request once we have routes
+            messages.append(teamserver_messages.ApplicationInventory(self.routes))
+
+        return messages
 
     def final_messages(self, context):
         # Request body is truncated to not overwhelm ContrastUI.
@@ -338,10 +359,9 @@ class BaseMiddleware(RoutesMixin):
         if self.settings.is_assess_enabled() and context.observed_route.signature:
             final_messages.append(context.observed_route)
 
-        if self.first_request:
+        if self.first_request and self.settings.is_inventory_enabled():
             # ApplicationUpdate message only sent at first request once we have routes
             final_messages.append(service_client.build_update_message(self.routes))
-            self.first_request = False
 
         return final_messages
 
