@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from contrast.api import Route
 from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
+from contrast.agent.middlewares.route_coverage.common import build_route
 from aiohttp.web_urldispatcher import DynamicResource
 
 
@@ -9,7 +11,7 @@ def create_aiohttp_routes(app):
     """
     Returns all the routes registered to a AioHttp app as a dict
     :param app: AioHttp app instance
-    :return: dict {route_id:  RouteCoverage}
+    :return: dict {route_id:  api.Route}
     """
     routes = {}
 
@@ -18,7 +20,7 @@ def create_aiohttp_routes(app):
 
             view_func = resource.handler
             name = view_func.__name__
-            route = build_aiohttp_route(name, view_func)
+            route = build_route(name, view_func)
 
             route_id = str(id(view_func))
 
@@ -29,15 +31,10 @@ def create_aiohttp_routes(app):
             )
             method_type = resource.method
             key = CoverageUtils.build_key(route_id, method_type)
-            routes[key] = CoverageUtils.build_route_coverage(
+            routes[key] = Route(
                 verb=method_type,
                 url=CoverageUtils.get_normalized_uri(_route_attr),
                 route=route,
             )
 
     return routes
-
-
-def build_aiohttp_route(view_func_name, view_func):
-    view_func_args = CoverageUtils.build_args_from_function(view_func)
-    return view_func_name + view_func_args
