@@ -11,8 +11,9 @@ from contrast.agent.middlewares.route_coverage.coverage_utils import (
     CoverageUtils,
     DEFAULT_ROUTE_METHODS,
 )
-from contrast.agent.settings_state import SettingsState
-from contrast.extern.backports.functools_lru_cache import lru_cache
+from contrast.api import Route
+from contrast.agent.settings import Settings
+from functools import lru_cache
 
 from contrast.extern import structlog as logging
 
@@ -21,7 +22,7 @@ logger = logging.getLogger("contrast")
 
 @lru_cache(maxsize=1)
 def is_django_1():
-    settings = SettingsState()
+    settings = Settings()
     return settings.framework.version.major == "1"
 
 
@@ -63,7 +64,7 @@ def get_method_info(pattern_or_resolver):
 
 def create_one_route(routes, method_type, method_arg_names, pattern_or_resolver):
     """
-    Create a new RouteCoverage object and adds it to routes dict
+    Create a new api.Route object and adds it to routes dict
 
     :param routes: dict of routes
     :param method_type:
@@ -77,7 +78,7 @@ def create_one_route(routes, method_type, method_arg_names, pattern_or_resolver)
 
     key = CoverageUtils.build_key(route_id, method_type)
 
-    routes[key] = CoverageUtils.build_route_coverage(
+    routes[key] = Route(
         verb=method_type, url=create_url(pattern_or_resolver), route=route
     )
 
@@ -119,7 +120,7 @@ def create_django_routes():
 
     In Django there is no implicit declaration of GET or POST. Often times decorators are used to fix this.
 
-    Returns a dict of key = id, value = RouteCoverage.
+    Returns a dict of key = id, value = api.Route.
     """
 
     from django.conf import settings
