@@ -2,7 +2,7 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.middlewares.route_coverage.coverage_utils import CoverageUtils
-from contrast.api import Finding
+from contrast.api import Finding, Route
 from contrast.utils.decorators import log_time
 
 from contrast.extern import structlog as logging
@@ -88,8 +88,8 @@ class RoutesMixin(object):
 
         logger.debug("Route visited: %s : %s", route.verb, route.url)
 
-        # save current route; this is used to append to findings
-        context.current_route = route
+        # save current route as a dtm; this is used to append to findings
+        context.current_route = route.to_dtm()
 
         # Currently we do not report an observed route if the route signature is empty.
         # As a team we've decided there isn't a meaningful default signature value
@@ -113,11 +113,7 @@ class RoutesMixin(object):
 
     def extend_middleware_routes(self, request_method, url, route_id, func):
         route = self.build_route(func, url)
-        route_coverage = CoverageUtils.build_route_coverage(
-            verb=request_method, url=url, route=route
-        )
-
-        self.routes[route_id] = route_coverage
+        self.routes[route_id] = Route(verb=request_method, url=url, route=route)
 
     def append_route_to_findings(self, context):
         """
