@@ -9,7 +9,7 @@ from contrast.agent import scope, rewriter
 from contrast.agent.assess.policy import string_propagation
 from contrast.agent.policy.applicator import register_import_hooks
 from contrast.agent.policy.loader import Policy
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.assess_extensions import cs_str
 from contrast.patches import (
     cs_str as cs_str_patches,
@@ -123,7 +123,7 @@ def enable_assess_patches(use_extension_hooks=True):
         )
         raise
 
-    use_extension_hooks = use_extension_hooks and not SettingsState().config.get(
+    use_extension_hooks = use_extension_hooks and not Settings().config.get(
         "agent.python.assess.use_pure_python_hooks"
     )
 
@@ -164,7 +164,7 @@ def disable_assess_patches():
 
 
 def _enable_patches():
-    settings = SettingsState()
+    settings = Settings()
 
     if settings.is_analyze_libs_enabled():
         register_library_patches()
