@@ -141,9 +141,9 @@ class BaseRule(object):
         Checks stack for code exceptions
         """
         # import here to prevent circular import
-        from contrast.agent.settings_state import SettingsState
+        from contrast.agent.settings import Settings
 
-        code_exclusions = SettingsState().code_exclusion_matchers
+        code_exclusions = Settings().code_exclusion_matchers
         if not code_exclusions or len(code_exclusions) == 0:
             return False
 
