@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 import re
 
-from contrast.extern.six import iteritems, string_types
 
 import contrast
 from contrast.agent.protect.rule.base_rule import BaseRule
@@ -36,7 +35,7 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
     def find_attack(self, candidate_string=None, **kwargs):
         command_string = str(candidate_string) if candidate_string else None
 
-        attack = super(CmdInjection, self).find_attack(command_string, **kwargs)
+        attack = super().find_attack(command_string, **kwargs)
 
         if not attack and command_string:
             evaluations_for_rule = self.evaluations_for_rule()
@@ -122,13 +121,13 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
         if isinstance(user_input, list) and user_input:
             return False
 
-        return super(CmdInjection, self).skip_protect_analysis(user_input, args, kwargs)
+        return super().skip_protect_analysis(user_input, args, kwargs)
 
     def convert_input(self, user_input):
         if isinstance(user_input, list):
             user_input = " ".join(user_input)
 
-        return super(CmdInjection, self).convert_input(user_input)
+        return super().convert_input(user_input)
 
     def infilter(self, match_string, **kwargs):
         context = contrast.CS__CONTEXT_TRACKER.current()
@@ -151,7 +150,7 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
             evaluation = evaluations_for_rule[0]
             self.detect_command_chaining(original_command, evaluation)
 
-        super(CmdInjection, self).infilter(match_string, **kwargs)
+        super().infilter(match_string, **kwargs)
 
     def detect_command_backdoor(self, context, command):
         """
@@ -183,12 +182,12 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
     def find_matching_parameter(self, context, command):
         request = context.request
 
-        if request and isinstance(command, string_types):
+        if request and isinstance(command, str):
             normalized_command = self._normalize_str(command)
 
             parameters = request.params.dict_of_lists()
 
-            for parameter_key, parameter_values in iteritems(parameters):
+            for parameter_key, parameter_values in parameters.items():
                 param = self._get_param_in_command(parameter_values, normalized_command)
                 if param:
                     return parameter_key, param
