@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import json
 from contrast.agent.protect.rule.nosql_injection.mongo_nosql_scanner import (
@@ -49,7 +49,7 @@ class NoSqlInjection(SqlInjection):
         if not isinstance(user_input, (str, bytes)):
             user_input = obj_to_str(user_input)
 
-        return super(NoSqlInjection, self).convert_input(user_input)
+        return super().convert_input(user_input)
 
 
 @fail_quietly("Failed to convert nosql obj input to str", return_value="")
