@@ -15,7 +15,7 @@ from contrast.agent import scope
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.assess.utils import clear_properties
 from contrast.agent.request_context import RequestContext
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.patches.rewriter import contrast__add, contrast__append
 from contrast.utils.decorators import fail_safely
 from contrast.utils.environ import test_environ
@@ -232,7 +232,7 @@ def register():
 
     sys.meta_path.insert(0, ContrastMetaPathFinder())
 
-    settings = SettingsState()
+    settings = Settings()
     settings.rewriter_enabled = True
 
     logger.debug("enabled AST rewriter")
