@@ -6,7 +6,7 @@ Functions for communication with speedracer to receive input analysis
 """
 import contrast
 from contrast.agent import service_client
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.api.settings_pb2 import ProtectionRule
 from contrast.utils.exceptions.security_exception import SecurityException
 
@@ -54,7 +54,7 @@ def create_activity_from_speedracer_input_analysis(speedracer_input_analysis, co
     if speedracer_input_analysis is None:
         return
 
-    settings = SettingsState()
+    settings = Settings()
 
     for evaluation in speedracer_input_analysis.results:
         rule = settings.defend_rules[evaluation.rule_id]
