@@ -15,7 +15,7 @@ import threading
 from contrast import __version__
 from contrast.agent import scope
 from contrast import AGENT_CURR_WORKING_DIR
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.extern import structlog as logging
 from requests import post as post_request, get as get_request
 from contrast.utils import service_util
@@ -63,7 +63,7 @@ class Telemetry(Singleton, threading.Thread):
         self.enabled = True
         self.message_q = None
         self.stopped = False
-        self.settings = SettingsState()
+        self.settings = Settings()
 
         self._check_is_public_build()
         self._check_enabled()
