@@ -2,7 +2,8 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
-from contrast.agent.settings_state import SettingsState
+from contrast.agent import scope
+from contrast.agent.settings import Settings
 
 DATABASE_MYSQL = "MySQL"
 DATABASE_PG = "PostgreSQL"
@@ -16,10 +17,14 @@ ACTION_EXECUTE = "execute"
 def apply_rule(patch_policy, orig_func, args, kwargs):
     context = contrast.CS__CONTEXT_TRACKER.current()
 
-    if context is not None and SettingsState().is_protect_enabled():
+    if (
+        context is not None
+        and Settings().is_protect_enabled()
+        and not scope.in_contrast_scope()
+    ):
         for node in patch_policy.trigger_nodes:
             rule_name = node.rule.name
-            rule = SettingsState().defend_rules.get(rule_name)
+            rule = Settings().defend_rules.get(rule_name)
             if not rule or not rule.enabled:
                 continue
 
