@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import string_types, binary_type
-
-from contrast.agent import scope
 from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy import trigger_policy
 from contrast.utils.decorators import fail_safely
@@ -14,7 +11,7 @@ def apply_rule(module_name, method_name, result, args, kwargs):
     if len(args) < 1:
         return
 
-    if not isinstance(args[0], string_types + (binary_type, bytearray)):
+    if not isinstance(args[0], (str, bytes, bytearray)):
         return
 
     policy = Policy()
@@ -22,5 +19,4 @@ def apply_rule(module_name, method_name, result, args, kwargs):
 
     trigger_nodes = trigger_rule.find_trigger_nodes(module_name, method_name)
 
-    with scope.trigger_scope():
-        trigger_policy.apply(trigger_rule, trigger_nodes, result, args, kwargs)
+    trigger_policy.apply(trigger_rule, trigger_nodes, result, args, kwargs)
