@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 Contrast Security, Inc.
+ * Copyright © 2022 Contrast Security, Inc.
  * See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
  */
 /* Python requires its own header to always be included first */
@@ -12,10 +12,6 @@
 #include <contrast/assess/patches.h>
 #include <contrast/assess/propagate.h>
 
-#if PY_MAJOR_VERSION < 3
-#define PY2
-#endif /* PY_MAJOR_VERSION == 3 */
-
 #define apply_or_fail(applyfunc, funchook)                          \
     do {                                                            \
         if ((applyfunc)((funchook)) != 0) {                         \
@@ -90,9 +86,6 @@ PyObject *enable_required_hooks(PyObject *self, PyObject *arg) {
     apply_or_fail(apply_stream_patches, funchook);
     apply_or_fail(apply_repr_patches, funchook);
     apply_or_fail(apply_cast_patches, funchook);
-#ifdef PY2
-    apply_or_fail(apply_exec_patches, funchook);
-#endif
 
     Py_RETURN_NONE;
 }
