@@ -73,12 +73,19 @@ class AgentConfig(object):
         self._config[key] = value
 
     def log_config(self):
-        """Log configuration values EXCEPT API information containing sensitive data"""
-        config_no_api = {
-            key: self._config[key] for key in self._config if "api" not in key
-        }
+        """
+        Log configuration values.
 
-        logger.info("Current Configuration", **config_no_api)
+        Config values deemed sensitive are logged as **REDACTED** unless unassigned.
+        """
+        sensitive_keys = ["api.service_key", "api.api_key", "api.proxy.url"]
+
+        redacted_config = self._config.copy()
+        for key in sensitive_keys:
+            if redacted_config[key]:
+                redacted_config[key] = "**REDACTED**"
+
+        logger.info("Current Configuration", **redacted_config)
 
     def override_configs(self):
         """
@@ -312,6 +319,12 @@ class Agent(ConfigBuilder):
                 default_value=False,
                 type_cast=utils.str_to_bool,
             ),
+            # TODO: PYT-837 remove this config once exclusions are implemented
+            ConfigOption(
+                name="python.url_exclusion_patterns",
+                default_value=[],
+                type_cast=utils.strs_to_regexes,
+            ),
             ConfigOption(
                 name="python.assess.use_pure_python_hooks",
                 default_value=False,
@@ -360,6 +373,14 @@ class Api(ConfigBuilder):
             ConfigOption(
                 name="request_audit.responses", default_value=False, type_cast=bool
             ),
+            ConfigOption(
+                name="certificate.enable", default_value=False, type_cast=bool
+            ),
+            ConfigOption(name="certificate.ca_file", default_value="", type_cast=str),
+            ConfigOption(name="certificate.cert_file", default_value="", type_cast=str),
+            ConfigOption(name="certificate.key_file", default_value="", type_cast=str),
+            ConfigOption(name="proxy.enable", default_value=False, type_cast=bool),
+            ConfigOption(name="proxy.url", default_value="", type_cast=str),
         ]
 
 
