@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
 import sys
@@ -46,7 +46,7 @@ class DjangoWSGIMiddleware(WSGIMiddleware):
             DjangoHttpOnlyRule(),
         ]
 
-        super(DjangoWSGIMiddleware, self).__init__(wsgi_app, self.app_name)
+        super().__init__(wsgi_app, self.app_name)
 
     def get_app_name(self):
         try:
