@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.wsgi.middleware import WSGIMiddleware
 from contrast.agent.middlewares.app_finder import get_original_app_or_fail
@@ -37,7 +37,7 @@ class FalconMiddleware(WSGIMiddleware):
 
         # Since Falcon is WSGI-based, there is no way to retrieve the app name.
         # Use common config to define an app name.
-        super(FalconMiddleware, self).__init__(_app, app_name="Falcon Application")
+        super().__init__(_app, app_name="Falcon Application")
 
     @fail_safely("Unable to get route coverage", return_value={})
     def get_route_coverage(self):
