@@ -16,8 +16,8 @@ from contrast.agent.middlewares.response_wrappers.fastapi_response_wrapper impor
 )
 from contrast.agent.middlewares.route_coverage.fastapi_routes import (
     create_fastapi_routes,
-    build_fastapi_route,
 )
+from contrast.agent.middlewares.route_coverage.common import build_route
 from contrast.agent.request_context import RequestContext
 from contrast.agent.asgi import starlette_request_to_environ, track_scope_sources
 from contrast.extern import structlog as logging
@@ -52,8 +52,13 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
         Instead of implementing a __call__ function, we rely on
         BaseHTTPMiddleware's __call__ func which calls self.dispatch_func.
         """
-        with Profiler(request.scope.get("path")):
+        path = request.scope.get("path")
+
+        with Profiler(path):
             if self.is_agent_enabled():
+                if self.settings.ignore_request(path):
+                    return await self.call_without_agent_async(request, call_next, path)
+
                 with scope_.contrast_scope():
                     environ = await starlette_request_to_environ(request)
                 context = RequestContext(environ)
@@ -61,16 +66,16 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
                 with contrast.CS__CONTEXT_TRACKER.lifespan(context):
                     return await self.call_with_agent(context, request, call_next)
 
-            return await self.call_without_agent_async(request, call_next)
+            return await self.call_without_agent_async(request, call_next, path)
 
-    async def call_without_agent_async(self, request: Request, call_next):
-        super().call_without_agent()
+    async def call_without_agent_async(self, request: Request, call_next, path):
+        super().call_without_agent(path)
         return await call_next(request)
 
     async def call_with_agent(self, context, request: Request, call_next):
         scope = request.scope
-
-        self.log_start_request_analysis(scope.get("path"))
+        path = scope.get("path")
+        self.log_start_request_analysis(path)
 
         track_scope_sources(context, scope)
         try:
@@ -86,16 +91,18 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
 
             self.postfilter(context)
             self.check_for_blocked(context)
+            self.handle_ensure(context, context.request)
             return response
 
         except ContrastServiceException as e:
+            # handle_ensure should not be called here
             logger.warning(e)
-            return await self.call_without_agent_async(request, call_next)
+            return await self.call_without_agent_async(request, call_next, path)
         except Exception as e:
+            self.handle_ensure(context, context.request)
             response = self.handle_exception(e)
             return response
         finally:
-            self.handle_ensure(context, context.request)
             self.log_end_request_analysis(context.request.path)
             if self.settings.is_assess_enabled():
                 contrast.STRING_TRACKER.ageoff()
@@ -123,7 +130,7 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
 
     @fail_safely("Unable to build route", return_value="")
     def build_route(self, view_func, url):
-        return build_fastapi_route(url, view_func)
+        return build_route(url, view_func)
 
     def generate_security_exception_response(self):
         return PlainTextResponse(self.OVERRIDE_MESSAGE, SecurityException.STATUS_CODE)
