@@ -14,7 +14,7 @@ from contrast.agent import scope
 from contrast.agent.policy import patch_manager
 from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.policy.loader import Policy
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.utils.decorators import fail_safely
 from contrast.utils.library_reader.patched_state import DistributionContext
 from contrast.utils.library_reader.utils import (
@@ -182,7 +182,7 @@ def post__import__analysis(
 def build_import_patch(orig_func, _):
     def import_patch(*args, **kwargs):
         context = contrast.CS__CONTEXT_TRACKER.current()
-        settings = SettingsState()
+        settings = Settings()
 
         perform_analysis = False
         possible_sys_module_keys = None
