@@ -4,11 +4,9 @@
 import threading
 import queue
 
-from requests import put as put_request
-
 from .teamserver_messages import BaseTsMessage
 from contrast.agent import scope
-from contrast.agent.settings_state import SettingsState
+from contrast.agent.settings import Settings
 from contrast.reporting import RequestAudit
 from contrast.extern import structlog as logging
 
@@ -18,7 +16,7 @@ logger = logging.getLogger("contrast")
 class ReportingClient(threading.Thread):
     def __init__(self):
         self.message_q = queue.Queue(maxsize=128)
-        self.settings = SettingsState()
+        self.settings = Settings()
         self.request_audit = (
             RequestAudit(self.settings.config)
             if self.settings.config.is_request_audit_enabled
@@ -40,7 +38,8 @@ class ReportingClient(threading.Thread):
             while not self.stopped and self.settings.is_agent_config_enabled():
                 try:
                     msg = self.message_q.get(block=True, timeout=5)
-                    self.send_message(msg)
+                    response = self.send_message(msg)
+                    msg.process_response(response)
                 except queue.Empty:
                     pass
 
@@ -50,14 +49,36 @@ class ReportingClient(threading.Thread):
                 "Sending message to Teamserver %s", type(msg), direct_to_teamserver=1
             )
 
+            cert = None
             url = msg.base_url + msg.path
-            response = put_request(
+
+            if self.settings.is_cert_verification_enabled:
+                if (
+                    not self.settings.ca_file
+                    or not self.settings.client_cert_file
+                    or not self.settings.client_private_key
+                ):
+                    logger.error(
+                        "Unable to communicate with Contrast. "
+                        "Certificate configuration is not set properly.",
+                        direct_to_teamserver=1,
+                    )
+                    self.settings.config.put("enable", False)
+                    return None
+
+                cert = (
+                    self.settings.client_cert_file,
+                    self.settings.client_private_key,
+                )
+
+            response = msg.request_method(
                 url,
                 json=msg.body,
                 proxies=msg.proxy,
                 headers=msg.headers,
                 allow_redirects=False,
-                verify=True,
+                verify=self.settings.ca_file if self.settings.ca_file else True,
+                cert=cert,
             )
 
             logger.debug("Teamserver response: %s", response, direct_to_teamserver=1)
@@ -65,15 +86,15 @@ class ReportingClient(threading.Thread):
             if self.request_audit:
                 self.request_audit.audit(msg, response)
 
-            self.settings.process_ts_response(response)
-
             return response
 
-        except Exception:
+        except Exception as e:
             logger.exception(
-                "Could not send message from reporting queue.",
+                "Failed to send message to Contrast: %s",
+                e,
                 direct_to_teamserver=1,
             )
+            self.settings.config.put("enable", False)
 
         return None
 
