@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern.wrapt import ObjectProxy
 
@@ -63,7 +63,7 @@ class BaseStreamProxy(ObjectProxy):
     cs__source_tags = None
 
     def __init__(self, wrapped):
-        super(BaseStreamProxy, self).__init__(wrapped)
+        super().__init__(wrapped)
         for method_name in self.CS__METHOD_NAMES:
             setattr(self, method_name, getattr(wrapped, method_name, None))
 
@@ -88,7 +88,7 @@ class ContrastWsgiStreamProxy(BaseStreamProxy):
     """
 
     def __init__(self, wrapped):
-        super(ContrastWsgiStreamProxy, self).__init__(wrapped)
+        super().__init__(wrapped)
         instrument_source_stream(self)
 
 
@@ -101,7 +101,7 @@ class ContrastFileProxy(BaseStreamProxy):
     """
 
     def __init__(self, wrapped):
-        super(ContrastFileProxy, self).__init__(wrapped)
+        super().__init__(wrapped)
         instrument_source_stream(self)
 
 
@@ -113,7 +113,7 @@ class ContrastBufferedReaderProxy(BaseStreamProxy):
     """
 
     def __init__(self, wrapped):
-        super(ContrastBufferedReaderProxy, self).__init__(wrapped)
+        super().__init__(wrapped)
         instrument_source_stream(self)
 
 
@@ -123,7 +123,7 @@ class ContrastRawIOProxy(BaseRawIOProxy):
     """
 
     def __init__(self, wrapped):
-        super(ContrastRawIOProxy, self).__init__(wrapped)
+        super().__init__(wrapped)
         instrument_source_stream(self)
 
 
