@@ -53,6 +53,7 @@ def setup_agent_logger(config):
     )
 
     logger = logging.getLogger(LOGGER_NAME)
+
     _set_logger_info(logger, config, path, level)
     _lock_logger(logger, config)
 
@@ -134,9 +135,11 @@ def _get_handler(path):
     else:
         try:
             handler = logging.FileHandler(path)
-        except Exception:
+        except Exception as e:
+            print(e)
             # path could be '' or None
             handler = logging.StreamHandler()
+
     return handler
 
 
